@@ -14,7 +14,7 @@ from . import events
 from . import proxy_macos
 from .config import load_config
 from .backend_client import BackendAPIError, build_backend_api_from_context
-from .packaging_utils import get_mitmdump_path
+from .packaging_utils import find_mitmdump_executable
 
 # added: logging & forwarding deps
 import os
@@ -309,20 +309,10 @@ async def start(req: Request) -> Dict[str, Any]:
             "proxyEnabled": False,
         }
 
-    # Step 1: preflight check for mitmdump
-    try:
-        mitmdump_path = get_mitmdump_path()
-        # Check if the path exists and is executable
-        if mitmdump_path == "mitmdump":
-            # Fallback to system check
-            mitmdump_path = shutil.which("mitmdump")
-        if not mitmdump_path or not os.path.exists(mitmdump_path):
-            return {"ok": False, "error": "mitmdump not found. Please install mitmproxy (brew install mitmproxy)."}
-    except Exception:
-        # Fallback to original method
-        mitmdump_path = shutil.which("mitmdump")
-        if not mitmdump_path:
-            return {"ok": False, "error": "mitmdump not found. Please install mitmproxy (brew install mitmproxy)."}
+    # Step 1: preflight check for mitmdump using enhanced finder
+    mitmdump_path = find_mitmdump_executable()
+    if not mitmdump_path:
+        return {"ok": False, "error": "mitmdump not found. Please install mitmproxy (pip install mitmproxy or brew install mitmproxy)."}
 
     # Prepare vars
     bypass_domains = body.get("bypassDomains") or []
@@ -332,6 +322,14 @@ async def start(req: Request) -> Dict[str, Any]:
     _proxy_services = None
     _proxy_enabled = False
 
+    # 单轮 /start 防抖与状态重置：确保最多弹一次管理员授权，且仅在启用成功后才允许恢复
+    try:
+        proxy_macos._helper_install_attempted_once = False
+        proxy_macos._proxy_applied_this_round = False
+    except Exception:
+        pass
+    proxy_applied = False
+
     # Step 2: take proxy snapshot on macOS (Darwin) before starting
     is_darwin = platform.system() == "Darwin"
     if is_darwin:
@@ -385,6 +383,7 @@ async def start(req: Request) -> Dict[str, Any]:
         try:
             services = _proxy_services or proxy_macos.detect_services()
             proxy_macos.enable_system_proxy(services, port, bypass_domains)
+            proxy_applied = True
             _proxy_enabled = True
             process.set_proxy_enabled(True)
             if hasattr(process, "set_last_error"):
@@ -400,14 +399,14 @@ async def start(req: Request) -> Dict[str, Any]:
             except Exception as stop_err:
                 _logger.error("[start] 停止 mitmdump 失败: %s", stop_err)
                 
-            # Restore if snapshot exists
+            # 仅当本轮确实已启用过系统代理时才恢复快照；否则跳过，避免额外弹窗
             try:
-                if _proxy_snapshot:
-                    _logger.info("[start] 恢复代理设置快照...")
+                if proxy_applied and _proxy_snapshot:
+                    _logger.info("[start] 恢复代理设置快照（已启用过代理）...")
                     proxy_macos.restore_proxy_state(_proxy_snapshot)
                     _logger.info("[start] 代理设置已恢复")
                 else:
-                    _logger.info("[start] 无代理快照需要恢复")
+                    _logger.info("[start] 跳过恢复：未启用过代理或无快照")
             except Exception as restore_err:
                 _logger.error("[start] 恢复代理设置失败: %s", restore_err)
                 
@@ -455,10 +454,10 @@ async def stop() -> Dict[str, Any]:
     global _proxy_snapshot, _proxy_services, _proxy_enabled
     # Always try to stop mitmdump
     res = process.stop()
-    # Always attempt to restore proxy snapshot on macOS, even if process already exited (idempotent)
+    # 仅当本轮确实启用过系统代理时才执行恢复，避免无意义恢复与二次弹窗
     if platform.system() == "Darwin":
         try:
-            if _proxy_snapshot:
+            if _proxy_enabled and _proxy_snapshot:
                 proxy_macos.restore_proxy_state(_proxy_snapshot)
         except Exception:
             # best-effort restore
